@@ -5,6 +5,7 @@ options_init <- function(
   library = NULL,
   envir = NULL,
   format = NULL,
+  repository = NULL,
   iteration = NULL,
   error = NULL,
   memory = NULL,
@@ -27,6 +28,7 @@ options_init <- function(
     library = library,
     envir = envir,
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
@@ -51,6 +53,7 @@ options_new <- function(
   library = NULL,
   envir = NULL,
   format = NULL,
+  repository = NULL,
   iteration = NULL,
   error = NULL,
   memory = NULL,
@@ -73,6 +76,7 @@ options_new <- function(
     library = library,
     envir = envir,
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
@@ -102,6 +106,7 @@ options_class <- R6::R6Class(
     library = NULL,
     envir = NULL,
     format = NULL,
+    repository = NULL,
     iteration = NULL,
     error = NULL,
     memory = NULL,
@@ -123,6 +128,7 @@ options_class <- R6::R6Class(
       library = NULL,
       envir = NULL,
       format = NULL,
+      repository = NULL,
       iteration = NULL,
       error = NULL,
       memory = NULL,
@@ -144,6 +150,7 @@ options_class <- R6::R6Class(
       self$library <- library
       self$envir <- envir
       self$format <- format
+      self$repository <- repository
       self$iteration <- iteration
       self$error <- error
       self$memory <- memory
@@ -166,6 +173,7 @@ options_class <- R6::R6Class(
         imports = self$get_imports(),
         library = self$get_library(),
         format = self$get_format(),
+        repository = self$get_repository(),
         iteration = self$get_iteration(),
         error = self$get_error(),
         memory = self$get_memory(),
@@ -188,6 +196,7 @@ options_class <- R6::R6Class(
       self$set_imports(list$imports)
       self$set_library(list$library)
       self$set_format(list$format)
+      self$set_repository(list$repository)
       self$set_iteration(list$iteration)
       self$set_error(list$error)
       self$set_memory(list$memory)
@@ -210,6 +219,7 @@ options_class <- R6::R6Class(
       self$library <- NULL
       self$envir <- NULL
       self$format <- NULL
+      self$repository <- NULL
       self$iteration <- NULL
       self$error <- NULL
       self$memory <- NULL
@@ -243,6 +253,9 @@ options_class <- R6::R6Class(
     get_format = function() {
       self$format %|||% "rds"
     },
+    get_repository = function() {
+      self$repository %|||% "local"
+    },
     get_iteration = function() {
       self$iteration %|||% "vector"
     },
@@ -309,6 +322,10 @@ options_class <- R6::R6Class(
       self$validate_format(format)
       self$format <- format
     },
+    set_repository = function(repository) {
+      self$validate_repository(repository)
+      self$repository <- repository
+    },
     set_iteration = function(iteration) {
       self$validate_iteration(iteration)
       self$iteration <- iteration
@@ -389,12 +406,18 @@ options_class <- R6::R6Class(
     validate_format = function(format) {
       tar_assert_format(format)
     },
+    validate_repository = function(repository) {
+      tar_assert_repository(repository)
+    },
     validate_iteration = function(iteration) {
       tar_assert_flag(iteration, c("vector", "list", "group"))
     },
     validate_error = function(error) {
       deprecate_error_workspace(error)
-      tar_assert_flag(error, c("stop", "continue", "abridge", "workspace"))
+      tar_assert_flag(
+        error,
+        c("stop", "continue", "abridge", "workspace", "null")
+      )
     },
     validate_memory = function(memory) {
       tar_assert_flag(memory, c("persistent", "transient"))
@@ -447,6 +470,7 @@ options_class <- R6::R6Class(
       self$validate_library(self$get_library())
       self$validate_envir(self$get_envir())
       self$validate_format(self$get_format())
+      self$validate_repository(self$get_repository())
       self$validate_iteration(self$get_iteration())
       self$validate_error(self$get_error())
       self$validate_memory(self$get_memory())
