@@ -64,7 +64,7 @@ tar_renv <- function(
   ),
   path = "_targets_packages.R",
   callr_function = callr::r,
-  callr_arguments = targets::callr_args_default(callr_function),
+  callr_arguments = targets::tar_callr_args_default(callr_function),
   envir = parent.frame(),
   script = targets::tar_config_get("script")
 ) {
