@@ -9,12 +9,20 @@
 #'   non-default settings of various optional backends for data storage
 #'   and high-performance computing. The `tar_resources()` function
 #'   is a helper to supply those settings in the correct manner.
-#'   Resources are all-or-nothing: if you specify any resources
-#'   with [tar_target()], all the resources from `tar_option_get("resources")`
-#'   are dropped for that target. In other words, if you write
-#'   `tar_option_set(resources = resources_1)` and then
-#'   `tar_target(x, my_command(), resources = resources_2)`, then everything
-#'   in `resources_1` is discarded for target `x`.
+#'
+#'   In `targets` version 0.12.2 and above, resources are inherited one-by-one
+#'   in nested fashion from `tar_option_get("resources")`.
+#'   For example, suppose you set
+#'   `tar_option_set(resources = tar_resources(aws = my_aws))`,
+#'   where `my_aws` equals `tar_resources_aws(bucket = "x", prefix = "y")`.
+#'   Then, `tar_target(data, get_data()` will have bucket `"x"` and
+#'   prefix `"y"`. In addition, if `new_resources` equals
+#'   `tar_resources(aws = tar_resources_aws(bucket = "z")))`, then
+#'   `tar_target(data, get_data(), resources = new_resources)`
+#'   will use the new bucket `"z"`, but it will still use the prefix `"y"`
+#'   supplied through `tar_option_set()`. (In `targets` 0.12.1 and below,
+#'   options like `prefix` do not carry over from `tar_option_set()` if you
+#'   supply non-default resources to `tar_target()`.)
 #' @return A list of objects of class `"tar_resources"` with
 #'   non-default settings of various optional backends for data storage
 #'   and high-performance computing.
@@ -80,15 +88,15 @@
 #'   )
 #' )
 tar_resources <- function(
-  aws = NULL,
-  clustermq = NULL,
-  feather = NULL,
-  fst = NULL,
-  future = NULL,
-  gcp = NULL,
-  parquet = NULL,
-  qs = NULL,
-  url = NULL
+  aws = tar_option_get("resources")$aws,
+  clustermq = tar_option_get("resources")$clustermq,
+  feather = tar_option_get("resources")$feather,
+  fst = tar_option_get("resources")$fst,
+  future = tar_option_get("resources")$future,
+  gcp = tar_option_get("resources")$gcp,
+  parquet = tar_option_get("resources")$parquet,
+  qs = tar_option_get("resources")$qs,
+  url = tar_option_get("resources")$url
 ) {
   envir <- environment()
   names <- names(formals(tar_resources))
@@ -105,6 +113,7 @@ tar_resources <- function(
     if (!is.null(value)) {
       tar_assert_inherits(value, class, message)
       out[[name]] <- value
+      resources_validate(value)
     }
   }
   out
