@@ -11,6 +11,7 @@ tar_test("validate non-default options", {
     library = "path",
     envir = new.env(),
     format = "qs",
+    repository = "aws",
     iteration = "list",
     error = "continue",
     memory = "transient",
@@ -35,6 +36,7 @@ tar_test("export", {
     imports = "targets",
     library = "path",
     format = "qs",
+    repository = "aws",
     iteration = "list",
     error = "continue",
     memory = "transient",
@@ -57,6 +59,7 @@ tar_test("export", {
     imports = "targets",
     library = "path",
     format = "qs",
+    repository = "aws",
     iteration = "list",
     error = "continue",
     memory = "transient",
@@ -85,6 +88,7 @@ tar_test("import", {
     imports = "targets",
     library = "path",
     format = "qs",
+    repository = "aws",
     iteration = "list",
     error = "continue",
     memory = "transient",
@@ -109,6 +113,7 @@ tar_test("import", {
   expect_equal(x$get_imports(), "targets")
   expect_equal(x$get_library(), "path")
   expect_equal(x$get_format(), "qs")
+  expect_equal(x$get_repository(), "aws")
   expect_equal(x$get_iteration(), "list")
   expect_equal(x$get_error(), "continue")
   expect_equal(x$get_memory(), "transient")
@@ -188,6 +193,16 @@ tar_test("format", {
   expect_error(x$set_format("invalid"), class = "tar_condition_validate")
 })
 
+tar_test("repository", {
+  x <- options_init()
+  expect_equal(x$get_repository(), "local")
+  x$set_repository("aws")
+  expect_equal(x$get_repository(), "aws")
+  x$reset()
+  expect_equal(x$get_repository(), "local")
+  expect_error(x$set_repository(123), class = "tar_condition_validate")
+})
+
 tar_test("iteration", {
   x <- options_init()
   expect_equal(x$get_iteration(), "vector")
