@@ -1,5 +1,5 @@
 tar_test("dynamic urls work", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
   url <- "https://httpbin.org/etag/test"
@@ -36,7 +36,7 @@ tar_test("dynamic urls work", {
 })
 
 tar_test("dynamic urls in dynamic branches work", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
   url <- "https://httpbin.org/etag/test"
@@ -70,7 +70,7 @@ tar_test("dynamic urls in dynamic branches work", {
 })
 
 tar_test("dynamic urls work from a custom data store", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
   url <- "https://httpbin.org/etag/test"
@@ -120,7 +120,7 @@ tar_test("dynamic urls work from a custom data store", {
 })
 
 tar_test("tar_condition_run error on bad URL", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
   tar_script(tar_target(abc, "https://httpbin.org/status/404", format = "url"))
@@ -128,7 +128,7 @@ tar_test("tar_condition_run error on bad URL", {
 })
 
 tar_test("custom handle without error (unstructured resources)", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
   url <- "https://httpbin.org/etag/test"
@@ -158,7 +158,7 @@ tar_test("custom handle without error (unstructured resources)", {
 })
 
 tar_test("dynamic urls must return characters", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
   x <- target_init(
@@ -172,7 +172,7 @@ tar_test("dynamic urls must return characters", {
 })
 
 tar_test("url target gets custom curl handle (structured resources)", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   x <- tar_target_raw(
     name = "abc",
@@ -187,7 +187,7 @@ tar_test("url target gets custom curl handle (structured resources)", {
 })
 
 tar_test("url target gets custom curl handle (unstructured resources)", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   expect_warning(
     x <- tar_target_raw(
@@ -203,7 +203,7 @@ tar_test("url target gets custom curl handle (unstructured resources)", {
 })
 
 tar_test("bad curl handle throws an error (structrued resources)", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
   url <- "https://httpbin.org/etag/test"
@@ -222,12 +222,12 @@ tar_test("bad curl handle throws an error (structrued resources)", {
   })
   expect_error(
     tar_make(callr_function = NULL),
-    class = "tar_condition_validate"
+    class = "tar_condition_run"
   )
 })
 
 tar_test("bad curl handle throws an error (unstructrued resources)", {
-  skip_on_cran()
+  skip_cran()
   skip_if_not_installed("curl")
   skip_if_offline()
   url <- "https://httpbin.org/etag/test"
